@@ -1,6 +1,4 @@
-import json
 from typing import (
-    Dict, 
     Optional, 
     Union
 )
